txTwitter
=========

|txTwitter-ci|_ |txTwitter-cover|_

A Twisted-based client library for Twitter's API.


Status
------

Very alpha, but probably usable if the functionality you need has been
implemented.

Currently very incomplete (only a small number of API calls are supported), but
the architecture seems sound. All remaining API calls have ``TODO`` notes.

There are some moderately comprehensive docstrings in the code, but proper
documentation still needs to be written.


.. |txTwitter-ci| image:: https://travis-ci.org/jerith/txTwitter.png?branch=develop
.. _txTwitter-ci: https://travis-ci.org/jerith/txTwitter

.. |txTwitter-cover| image:: https://coveralls.io/repos/jerith/txTwitter/badge.png?branch=develop
.. _txTwitter-cover: https://coveralls.io/r/jerith/txTwitter
